Module node

Module node 

Ergo node REST API endpoints

Functions

get_blocks_header_id_proof_for_tx_id
GET on /blocks/{header_id}/proofFor/{tx_id} to request the merkle proof for a given transaction that belongs to the given header ID.
get_header
GET on /blocks/{header_id}/header endpoint
get_info
GET on /info endpoint
get_nipopow_proof_by_header_id
GET on /nipopow/proof/{minChainLength}/{suffixLength}/{headerId} endpoint
peer_discovery
Given a list of seed nodes, search for peer nodes with an active REST API on port 9053.