Ergo node REST API endpoints
Functions
- get_
blocks_ header_ id_ proof_ for_ tx_ id - GET on /blocks/{header_id}/proofFor/{tx_id} to request the merkle proof for a given transaction that belongs to the given header ID.
- get_
header - GET on /blocks/{header_id}/header endpoint
- get_
info - GET on /info endpoint
- get_
nipopow_ proof_ by_ header_ id - GET on /nipopow/proof/{minChainLength}/{suffixLength}/{headerId} endpoint
- peer_
discovery - Given a list of seed nodes, search for peer nodes with an active REST API on port 9053.